@@ -150,7 +150,8 @@ class MelodicIntervalTeacher(Teacher):
             # Do this loop to make sure two questions in a row does not have
             # the same top or bottom tone.
             while True:
-                self.m_tonika.randomize("f", "f'")
+                self.m_tonika, _ignore = utils.random_tonika_and_interval(L, H,
+                            self.m_question)
                 if not old_tonika:
                     break
                 if old_tonika != self.m_tonika and self.m_tonika + self.m_question[0] != old_toptone:
@@ -354,8 +355,16 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
         self.practise_box = gtk.VBox()
         self.practise_box.show()
         vbox.pack_start(self.practise_box, False)
+
+        box = gtk.VBox()
+        self.practise_box.pack_start(box, False, padding=gu.hig.SPACE_LARGE)
+        box.show()
         self.g_lesson_heading = gtk.Label()
-        self.practise_box.pack_start(self.g_lesson_heading, padding=18)
+        box.pack_start(self.g_lesson_heading)
+
+        self.g_lesson_description = gtk.Label()
+        self.g_lesson_description.set_line_wrap(True)
+        box.pack_start(self.g_lesson_description)
 
         self.action_area = gtk.HBox()
         self.action_area.show()
@@ -556,6 +565,13 @@ class Gui(gtk.VBox, cfg.ConfigUtils, QstatusDefs):
             self.g_lesson_heading.show()
         else:
             self.g_lesson_heading.hide()
+    def set_lesson_description(self, txt):
+        if txt:
+            self.g_lesson_description.set_text(gu.escape(txt))
+            self.g_lesson_description.set_use_markup(True)
+            self.g_lesson_description.show()
+        else:
+            self.g_lesson_description.hide()
     def on_start_practise(self):
         """
         Code that are common for all exercises. Not used by many now,
